<?php
namespace Pinpoint\Conesso\Model\Api\Transfer\Request;

use Pinpoint\Conesso\Api\Data\ProductSyncInterface;
use Magento\Catalog\Helper\Data as TaxHelper;
use Magento\CatalogInventory\Model\Stock\StockItemRepository;
use Pinpoint\Conesso\Model\Api\Access\Auth;

class ProductRequest extends AbstractRequest
{
    private $taxHelper;
    private $stockItemRepository;
    public function __construct(
        TaxHelper $taxHelper,
        StockItemRepository $stockItemRepository,
        Auth $authorization
    ) {
        $this->taxHelper = $taxHelper;
        $this->stockItemRepository = $stockItemRepository;
        parent::__construct($authorization);
    }
    public function buildData(mixed $item)
    {
        $parameters = [
            'id' => $item->getId(),
            'apiReferenceId' => "api-reference-123",
            'name' => $item->getName(),
            'description' => $item->getDescription() ?? null,
            'barcode' => $item->getUrlKey(),
            'uri' => $item->getProductUrl(),
            'sku' => $item->getSku(),
            'dateCreated' => date('Y-m-d\TH:i:s\Z',strtotime($item->getCreatedAt())),
            'dateUpdated' => date('Y-m-d\TH:i:s\Z',strtotime($item->getUpdatedAt())),
            'groupType' => 'standalone-product',
            'priceTax' => $this->getTaxPrice($item),
            'priceIncTax' => 100,
            'originalPrice' => $item->getPriceInfo()->getPrice('final_price')->getAmount()->getBaseAmount(),
            'price' => (int)$item->getPrice(),
            'weight' => 0,
            'weightUnit' => "kg",
            'stockQuantity' => 99,
            'visibility' => 'not-individually',
            'status' => 'active'

        ];
        return $parameters;
    }

    private function getTaxPrice($product)
    {
        return $this->taxHelper->getTaxPrice($product, $product->getFinalPrice(), true);
    }
    public function sendRequest(mixed $data) : bool
    {
        try {
            if ($data['event_type'] == ProductSyncInterface::EVENT_TYPE_SAVE)
            {
                $parameters = $this->buildData($data['item']);
                $response = $this->getConnessoClient()->products()->create($parameters);
            }
//            if ($data['event_type'] == ProductSyncInterface::EVENT_TYPE_DELETE)
//            {
//                $response = $this->getConnessoClient()->products()->delete($data['item']->getId());
//            }
            return true;
        } catch(\Exception $e) {
            $x = $e->getMessage();
            return false;
        }
    }

    private function getStock($product)
    {
        return $this->stockItemRepository->get($product->getId())->getQty();
    }

}
